@@ -172,7 +172,7 @@ static void show_help(struct ts *ts) {
 	printf(" -c --ca-system <ca_sys>    | Process input EMM/ECM from <ca_sys>.\n");
 	printf("                            | Valid systems are: CONAX (default), CRYPTOWORKS,\n");
 	printf("                            .   IRDETO, SECA (MEDIAGUARD), VIACCESS,\n");
-	printf("                            .   VIDEOGUARD (NDS), NAGRA and DRECRYPT.\n");
+	printf("                            .   VIDEOGUARD (NDS), NAGRA, DRECRYPT and BULCRYPT.\n");
 	printf(" -C --caid <caid>           | Set CAID. Default: Taken from --ca-system.\n");
 	printf(" -Y --const-cw <codeword>   | Set constant code word for decryption.\n");
 	printf("                            . Example cw: a1a2a3a4a5a6a7a8b1b2b3b4b5b6b7b8\n");
@@ -351,6 +351,8 @@ static void parse_options(struct ts *ts, int argc, char **argv) {
 					ts->req_CA_sys = CA_NAGRA;
 				else if (strcasecmp("DRE-CRYPT", optarg) == 0 || strcasecmp("DRECRYPT", optarg) == 0)
 					ts->req_CA_sys = CA_DRECRYPT;
+				else if (strcasecmp("BULCRYPT", optarg) == 0)
+					ts->req_CA_sys = CA_BULCRYPT;
 				else
 					ca_err = 1;
 				break;
